==> minikube-1.32.0.tar.gz: minikube-1.32.0/site/content/en/docs/presentations/_index.md <==
---
title: "Presentations"
weight: 3.5
description: >
  Available online presentations about minikube
---

Presentations about the minikube project, mostly from the Kubernetes blog and the KubeCon conference.

## Conferences

### KubeCon EU 2023 (Amsterdam, Netherlands)

* [Minikube from CLI to GUI! - YouTube](https://youtu.be/74X1RmqfUzs) (38:35)
  * Medya Ghazizadeh, Google

### KubeCon EU 2022 (Valencia, Spain)

* [Deep Dive into Minikube - YouTube](https://youtu.be/Iyq_MlSku-I) (38:37)
  * Medya Ghazizadeh & Sharif Elgamal, Google

### KubeCon NA 2021 (Los Angeles, California)

* [A Deep Dive Into 5 years of Minikube - YouTube](https://youtu.be/GHczvbzuVvc) (47:47)
  * Medya Ghazizadeh, Google

### KubeCon EU 2021 (Online, Europe) - Virtual

* [Minikube & Three Different Local Kubernetes Learning Environments - YouTube](https://youtu.be/nqKYgeUtk8s) (32:48)
  * Anders Björklund & Predrag Rogic

### KubeCon EU 2020 (Amsterdam, Netherlands) - Virtual

* [Minikube - YouTube](https://youtu.be/xdoOmSSCxo8) (37:31)
  * Rohit Anand, NEC Corporation & Medya Ghazizadeh, Google

* [Improving the Performance of Your Kubernetes Cluster - YouTube](https://youtu.be/tvreJem3xIw) (36:10)
  * Priya Wadhwa, Google

### KubeCon NA 2019 (San Diego, California)

* [Minikube - YouTube](https://youtu.be/3giynG20f3I) (47:27)
  * Thomas Strömberg & Medya Ghazizadeh, Google

### Helm Summit EU 2019 (Amsterdam, The Netherlands)

* [Dancing with Helm, Skaffold and Minikube! - YouTube](https://youtu.be/Ww7JvxKY478) (35:26)
  * Medya Ghazizadeh, Google

### KubeCon CN 2019 (Shanghai, China)

* [Minikube: Bringing Kubernetes to the Next Billion Users - YouTube](https://youtu.be/ahb-_NBtOL0) (33:21)
  * Thomas Strömberg, Google

### KubeCon NA 2018 (Seattle, Washington)

* [Intro: Minikube - YouTube](https://youtu.be/2yBOVlonHQw) (38:49)
  * Thomas Strömberg & Bálint Pató, Google

* [Deep Dive: Minikube - YouTube](https://youtu.be/46-FXiSEfE4) (44:05)
  * Bálint Pató & Thomas Strömberg, Google

### KubeCon EU 2018 (Copenhagen, Denmark)

* [Minikube Intro - YouTube](https://youtu.be/4x0CZmF_U5o) (28:30)
  * Dan Lorenc, Google

## Kubernetes Blog

### 2019

2019-03-28, Kubernetes 1.14, Minikube 1.0.0

* [Running Kubernetes locally on Linux with Minikube - now with Kubernetes 1.14 support](https://kubernetes.io/blog/2019/03/28/running-kubernetes-locally-on-linux-with-minikube-now-with-kubernetes-1.14-support/)

### 2016

2016-07-11, Kubernetes 1.3, Minikube 0.5.0

* [Minikube: easily run Kubernetes locally](https://kubernetes.io/blog/2016/07/minikube-easily-run-kubernetes-locally/)

2016-05-30, Kubernetes 1.3, Minikube 0.1.0

* _This is the initial release of Minikube._

==> minikube-1.35.0.tar.gz: minikube-1.35.0/site/content/en/docs/presentations/_index.md <==
---
title: "Presentations"
weight: 3.5
description: >
  Available online presentations about minikube
---

Presentations about the minikube project, mostly from the Kubernetes blog and the KubeCon conference.

## Conferences

### KubeCon NA 2023 (Chicago, Illinois)

* [Minikube Project Update - YouTube](https://youtu.be/QTAijBeS5ys?si=OOyxOXnKkhiq-b1N) (30:43)
  * Medya Ghazizadeh, Google

### KubeCon EU 2023 (Amsterdam, Netherlands)

* [Minikube from CLI to GUI! - YouTube](https://youtu.be/74X1RmqfUzs) (38:35)
  * Medya Ghazizadeh, Google

### KubeCon EU 2022 (Valencia, Spain)

* [Deep Dive into Minikube - YouTube](https://youtu.be/Iyq_MlSku-I) (38:37)
  * Medya Ghazizadeh & Sharif Elgamal, Google

### KubeCon NA 2021 (Los Angeles, California)

* [A Deep Dive Into 5 years of Minikube - YouTube](https://youtu.be/GHczvbzuVvc) (47:47)
  * Medya Ghazizadeh, Google

### KubeCon EU 2021 (Online, Europe) - Virtual

* [Minikube & Three Different Local Kubernetes Learning Environments - YouTube](https://youtu.be/nqKYgeUtk8s) (32:48)
  * Anders Björklund & Predrag Rogic

### KubeCon EU 2020 (Amsterdam, Netherlands) - Virtual

* [Minikube - YouTube](https://youtu.be/xdoOmSSCxo8) (37:31)
  * Rohit Anand, NEC Corporation & Medya Ghazizadeh, Google

* [Improving the Performance of Your Kubernetes Cluster - YouTube](https://youtu.be/tvreJem3xIw) (36:10)
  * Priya Wadhwa, Google

### KubeCon NA 2019 (San Diego, California)

* [Minikube - YouTube](https://youtu.be/3giynG20f3I) (47:27)
  * Thomas Strömberg & Medya Ghazizadeh, Google

### Helm Summit EU 2019 (Amsterdam, The Netherlands)

* [Dancing with Helm, Skaffold and Minikube! - YouTube](https://youtu.be/Ww7JvxKY478) (35:26)
  * Medya Ghazizadeh, Google

### KubeCon CN 2019 (Shanghai, China)

* [Minikube: Bringing Kubernetes to the Next Billion Users - YouTube](https://youtu.be/ahb-_NBtOL0) (33:21)
  * Thomas Strömberg, Google

### KubeCon NA 2018 (Seattle, Washington)

* [Intro: Minikube - YouTube](https://youtu.be/2yBOVlonHQw) (38:49)
  * Thomas Strömberg & Bálint Pató, Google

* [Deep Dive: Minikube - YouTube](https://youtu.be/46-FXiSEfE4) (44:05)
  * Bálint Pató & Thomas Strömberg, Google

### KubeCon EU 2018 (Copenhagen, Denmark)

* [Minikube Intro - YouTube](https://youtu.be/4x0CZmF_U5o) (28:30)
  * Dan Lorenc, Google

## Kubernetes Blog

### 2019

2019-03-28, Kubernetes 1.14, Minikube 1.0.0

* [Running Kubernetes locally on Linux with Minikube - now with Kubernetes 1.14 support](https://kubernetes.io/blog/2019/03/28/running-kubernetes-locally-on-linux-with-minikube-now-with-kubernetes-1.14-support/)

### 2016

2016-07-11, Kubernetes 1.3, Minikube 0.5.0

* [Minikube: easily run Kubernetes locally](https://kubernetes.io/blog/2016/07/minikube-easily-run-kubernetes-locally/)

2016-05-30, Kubernetes 1.3, Minikube 0.1.0

* _This is the initial release of Minikube._
